# Create figure 5 from
# Rothkegel, L. O. M., Trukenbrod, H. A., Schü̈tt, H. H., Wichmann, F. A., & Engbert, R. (2016).
# Influence of initial fixation position in scene viewing. Vision research, 129, 33–49. 


# Clear Workspace 
rm(list=ls())


# Set working directory to current source location

dir <- dirname(parent.frame(2)$ofile)
setwd(dir)



# Packages needed
library(spatstat)
library(ggplot2)
library(Rmisc)
library(FNN)




# Read Data and image boundaries



Table<-read.table("Fixations.dat",header=TRUE)
range <- read.table("Image_Range.dat",header=TRUE)
ImageType<-read.table("Image_Type.dat")
# Define Image Center
cx<-sum(range$xrange)/2
cy<-sum(range$yrange)/2



# Define Starting Points of new Fixations
TP<-c(0,Table$offsetR)
TP[which(is.na(TP))]<-0
TP<-TP[-length(TP)]


# Reduce table to important variables
table<-data.frame((Table$xR+Table$xL)/2,(Table$yR+Table$yL)/2,Table$image,Table$fd,Table$nth,Table$id,Table$type,Table$fCroX,TP)
colnames(table)<-c("xPos","yPos","Image","FixDur","Fixation_Number","Subject","type","Start","Time")
table$type<-ImageType[table$Image,1]
table<-table[order(table$Image),]

rm(Table)

table$type[which(table$Image<33 & table$Image>16)]<-2

# Assign Factorized Starting Position
table$Start[which(table$Start<16)]<-1
table$Start[which(table$Start>16)]<-2


# Compute Saccade Amplitudes:
xdiff<-c(diff(table$xPos),NA)
ydiff<-c(diff(table$yPos),NA)
diff<-data.frame(xdiff,ydiff)
diff[which(diff(table$Subject)!=0),]<-NA
diff$sacle<-sqrt(diff$xdiff^2+diff$ydiff^2)
table$sacle<-diff$sacle



# Figure 4a of Saccade Amplitude Distributions:


Fig5a<-ggplot(table)+geom_line(aes(x=sacle,col=factor(type),linetype=factor(Start)),stat="density",size=0.7)+
  scale_colour_manual("Image Type", values = c(1,2,3,4),labels=c("1"="Balanced","2"="Pattern" ,"3"="Left Focus","4"="Right Focus")) +
  scale_linetype_manual("Start", values=c(1,3), labels=c("Left","Right")) + xlab("Saccade Amplitude [°]") + ylab("Density")+theme(legend.position="none")+ theme(legend.justification=c(1,1), legend.position=c(1,1),axis.text=element_text(size=20),
        axis.title=element_text(size=20),
        legend.title=element_text(size=20),legend.text=element_text(size=20))


# Figure 4b of Saccade Amplitude Mean over Time

T<-summarySE(table[-which(is.na(table$sacle)),],measurevar = "sacle" ,groupvars = c("Start","type","Fixation_Number"))


Fig5b<-ggplot(T[which(T$Fixation_Number<5),])+ geom_point(aes(x=Fixation_Number,y=sacle,col=factor(type)),size=4)+ geom_path(aes(x=Fixation_Number,y=sacle,col=factor(type),linetype=factor(Start)),size=1)+ 
  scale_colour_manual("Image Type", values = c(1,2,3,4),labels=c("1"="Balanced","2"="Pattern" ,"3"="Left Focus","4"="Right Focus")) +
  scale_linetype_manual("Start", values=c(1,3), labels=c("Left","Right")) + xlab("nth Saccade during Trial") + ylab("Saccade Amplitude [°]")+
theme(legend.justification=c(1,1), legend.position=c(1,1),axis.text=element_text(size=20),
      axis.title=element_text(size=20),
      legend.title=element_text(size=20),legend.text=element_text(size=20))



# Compute difference in first saccade length


F1<-summarySE(table[table$Fixation_Number==1,],measurevar = "sacle" ,groupvars = c("Start","type"))

# Reorder Factors for nicer presentation
F1$type2<-c(2,3,1,4,2,3,1,4)
F1<-F1[order(F1$type2),]
as.factor(F1$type2)
levels(F1$type2)<-c("neutral","pattern","left","right")


limits<-aes(ymin=sacle-se,ymax=sacle+se)

Fig5c<-ggplot(F1,aes(x=type2,y=sacle,group=factor(Start),linetype=factor(Start)))+geom_errorbar(limits,size=2,width=0.4)+geom_path(size=2)+geom_point(cex=6)+
  theme(legend.justification=c(1,1), legend.position=c(1,1),axis.text=element_text(size=20),
        axis.title=element_text(size=20),
        legend.title=element_text(size=20),legend.text=element_text(size=20),legend.key.size=unit(2,"cm"))+scale_linetype_manual("Start",values=c(1,2),labels=c("1"="Left","2"="Right"))+
  scale_x_discrete(breaks=c(1,2,3,4),labels=c("1"="Left Focus","2"="Balanced","3"="Pattern","4"="Right Focus"),limits=c(1,2,3,4))+ylab("First Saccade Amplitude [°]")+xlab("Image Type")




pdf("PDF/Figure5a.pdf",width=8,height=8)

Fig5a

dev.off()



pdf("PDF/Figure5b.pdf",width=8,height=8)

Fig5b

dev.off()

pdf("PDF/Figure5c.pdf",width=8,height=8)

Fig5c

dev.off()
